Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4322)

Unified Diff: chrome/installer/setup/install.h

Issue 1800303006: Fix the path of shortcuts with an icon in the current install dir. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix buildbot error Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/installer/setup/install.cc » ('j') | chrome/installer/setup/install.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/setup/install.h
diff --git a/chrome/installer/setup/install.h b/chrome/installer/setup/install.h
index 9cab9f7a9246ad9613c2ee20ba67783c0ed63ab8..9adb7a906c5a2fc6eb354cfa72cc16a37e758627 100644
--- a/chrome/installer/setup/install.h
+++ b/chrome/installer/setup/install.h
@@ -51,14 +51,15 @@ enum InstallShortcutLevel {
};
// Sets |new_target_path| as the new target path of all shortcuts in the
// location specified by |shortcut_location| and |dist| which point to a file:
// - In |old_target_dir| or one of its subdirectories, and,
// - Whose path ends with |old_target_path_suffix|.
void UpdatePerUserShortcutsInLocation(
const ShellUtil::ShortcutLocation shortcut_location,
BrowserDistribution* dist,
const base::FilePath& old_target_dir,
- const base::FilePath& old_target_path_suffix,
+ const base::FilePath& old_target_name_suffix,
const base::FilePath& new_target_path);
// Escape |att_value| as per the XML AttValue production
« no previous file with comments | « no previous file | chrome/installer/setup/install.cc » ('j') | chrome/installer/setup/install.cc » ('J')
@@ -51,14 +51,15 @@ enum InstallShortcutLevel {
};
// Sets |new_target_path| as the new target path of all shortcuts in the
-// location specified by |shortcut_location| and |dist| which point to a file:
-// - In |old_target_dir| or one of its subdirectories, and,
-// - Whose path ends with |old_target_path_suffix|.
+// location specified by |shortcut_location| and |dist| which either:
+// - Point to a file rooted at |old_target_dir| whose name ends in
+// |old_target_name_suffix|, or,
+// - Have an icon rooted at |old_target_dir|.
void UpdatePerUserShortcutsInLocation(
const ShellUtil::ShortcutLocation shortcut_location,

Powered by Google App Engine
This is Rietveld 408576698